import * as xstate from 'xstate';
import { ActorRefFrom, StateFrom } from 'xstate';
import { properties } from '@react-dive-ui/properties';

type CheckedState = "checked" | "unchecked" | "indeterminate";
type FormOptions = {
    name: string;
    required?: boolean;
};
type Context = {
    id: string;
    checkedState: CheckedState;
    disabled: boolean;
    value: string;
    form: FormOptions | null;
};
type Input = Pick<Context, "id"> & Partial<Pick<Context, "checkedState" | "disabled" | "value" | "form">>;
type Events = {
    type: "CHECK";
} | {
    type: "SET.CHECKED";
    checked: boolean;
} | {
    type: "SET.DISABLED";
    disabled: boolean;
} | {
    type: "SET.INDETERMINATE";
};
type Actions = {
    type: "toggleCheckedState";
} | {
    type: "setCheckedState";
    params: {
        checkedState: CheckedState;
    };
} | {
    type: "setDisabled";
    params: {
        disabled: boolean;
    };
} | {
    type: "syncInputWithIndeterminate";
} | {
    type: "dispatchCheckedEvent";
} | {
    type: "onChange";
};
type Guards = {
    type: "isDisabled";
} | {
    type: "isIndeterminate";
};
type Service = ActorRefFrom<typeof machine>;
type Send = Service["send"];
type State = StateFrom<typeof machine>;

declare const machine: xstate.StateMachine<Context, {
    type: "CHECK";
} | {
    type: "SET.CHECKED";
    checked: boolean;
} | {
    type: "SET.DISABLED";
    disabled: boolean;
} | {
    type: "SET.INDETERMINATE";
}, xstate.ProvidedActor, {
    type: "toggleCheckedState";
} | {
    type: "setCheckedState";
    params: {
        checkedState: CheckedState;
    };
} | {
    type: "setDisabled";
    params: {
        disabled: boolean;
    };
} | {
    type: "syncInputWithIndeterminate";
} | {
    type: "dispatchCheckedEvent";
} | {
    type: "onChange";
}, {
    type: "isDisabled";
} | {
    type: "isIndeterminate";
}, string, string, Input, xstate.NonReducibleUnknown, xstate.ResolveTypegenMeta<xstate.TypegenConstraint, {
    type: "CHECK";
} | {
    type: "SET.CHECKED";
    checked: boolean;
} | {
    type: "SET.DISABLED";
    disabled: boolean;
} | {
    type: "SET.INDETERMINATE";
}, xstate.ProvidedActor, {
    type: "toggleCheckedState";
} | {
    type: "setCheckedState";
    params: {
        checkedState: CheckedState;
    };
} | {
    type: "setDisabled";
    params: {
        disabled: boolean;
    };
} | {
    type: "syncInputWithIndeterminate";
} | {
    type: "dispatchCheckedEvent";
} | {
    type: "onChange";
}, {
    type: "isDisabled";
} | {
    type: "isIndeterminate";
}, string, string>>;

type ConnectReturn = {
    controlProps: ReturnType<typeof properties.button>;
    labelProps: ReturnType<typeof properties.label>;
    hiddenInputProps: ReturnType<typeof properties.input>;
};
declare function connect(state: State, send: Send): ConnectReturn;

export { Actions, CheckedState, ConnectReturn, Context, Events, FormOptions, Guards, Input, Send, Service, State, connect, machine };
